import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-stack-resource-rename",
    "0.0.8",
    __name__[0:-6],
    "cdk-stack-resource-rename@0.0.8.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
